<?php

class bt_bb_column extends BT_BB_Element {

	function handle_shortcode( $atts, $content ) {

		extract( shortcode_atts( apply_filters( 'bt_bb_extract_atts', array(
			'width'    		   			=> '',
			'align'   		   			=> 'left',
			'vertical_align'   			=> 'top',
			'animation'		   			=> '',
			'padding'          			=> 'normal',
			'background_image'      	=> '',
			'inner_background_image'    => '',
			'background_color' 			=> '',
			'inner_background_color' 	=> '',
			'opacity'	       			=> '',
			'triangle'					=> ''
		) ), $atts, $this->shortcode ) );

		$class = array( $this->shortcode );

		if ( $el_class != '' ) {
			$class[] = $el_class;
		}
		
		$id_attr = '';
		if ( $el_id != '' ) {
			$id_attr = 'id="' . esc_attr( $el_id ) . '"';
		}

		$array = explode( '/', $width );

		if ( empty( $array ) || $array[0] == 0 || $array[1] == 0 ) {
			$width = 12;
		} else {
			$top = $array[0];
			$bottom = $array[1];
			
			$width = 12 * $top / $bottom;
			
			if ( ! is_int( $width ) || $width < 1 || $width > 12 ) {
				$width = 12;
			}
		}

		if ( $width == 2 ) {
			$class[] = 'col-md-2 col-sm-4 col-ms-12';
		} else if ( $width == 3 ) {
			$class[] = 'col-md-3 col-sm-6 col-ms-12';
		} else if ( $width == 4 ) {
			$class[] = 'col-md-4 col-ms-12';
		} else if ( $width == 6 ) {
			$class[] = 'col-md-6 col-sm-12';	
		} else if ( $width == 8 ) {
			$class[] = 'col-md-8 col-ms-12';
		} else {
			$class[] = 'col-md-' . $width . ' ' . 'col-ms-12';
		}
		
		if ( $align != '' ) {
			$class[] = $this->prefix . 'align' . '_' . $align;
		}
		
		if ( $vertical_align != '' ) {
			$class[] = $this->prefix . 'vertical_align' . '_' . $vertical_align;
		}
		
		if ( $animation != 'no_animation' && $animation != '' ) {
			$class[] = $this->prefix . 'animation' . '_' . $animation;
			$class[] = 'animate';
		}

		if ( $padding != '' ) {
			$class[] = $this->prefix . 'padding' . '_' . $padding;
		}

		$triangle_style = '';

		if ( $background_color != '' ) {
			$background_color = bt_bb_column::hex2rgb( $background_color );
			if ( $opacity == '' ) {
				$opacity = 1;
			}
			$el_style .= 'background-color: rgba(' . $background_color[0] . ', ' . $background_color[1] . ', ' . $background_color[2] . ', ' . $opacity . ');';
			$triangle_style .= 'border-color: rgba(' . $background_color[0] . ', ' . $background_color[1] . ', ' . $background_color[2] . ', ' . $opacity . ');';
		}

		if ( $triangle != '' ) {
			$class[] = $this->prefix . 'triangle' . '_' . $triangle;
		}

		$el_inner_style = '';
		
		if ( $inner_background_color != '' ) {
			$inner_background_color = bt_bb_column::hex2rgb( $inner_background_color );
			if ( $opacity == '' ) {
				$opacity = 1;
			}
			$el_inner_style .= 'background-color:rgba(' . $inner_background_color[0] . ', ' . $inner_background_color[1] . ', ' . $inner_background_color[2] . ', ' . $opacity . ');';
		}
		
		if ( $inner_background_image != '' ) {
			$inner_background_image = wp_get_attachment_image_src( $inner_background_image, 'full' );
			$inner_background_image_url = $inner_background_image[0];
			$el_inner_style .= 'background-image:url(\'' . $inner_background_image_url . '\');';	
			$class[] = 'bt_bb_column_inner_background_image';
		}
		
		if ( $el_inner_style != '' ) {
			$el_inner_style = ' style="' . esc_attr( $el_inner_style ) . '"';
		}
		
		if ( $background_image != '' ) {
			$background_image = wp_get_attachment_image_src( $background_image, 'full' );
			$background_image_url = $background_image[0];
			$el_style .= 'background-image:url(\'' . $background_image_url . '\');';	
			$class[] = 'bt_bb_column_background_image';
		}
		
		$style_attr = '';

		if ( $el_style != '' ) {
			$style_attr = 'style="' . esc_attr( $el_style ) . '"';
		}


		if ( $triangle_style != '' ) {
			$triangle_style = ' style="' . esc_attr( $triangle_style ) . '"';
		}
		
		$class = apply_filters( $this->shortcode . '_class', $class, $atts );

		$output = '<div ' . $id_attr . ' class="' . implode( ' ', $class ) . '" ' . $style_attr . ' data-width="' . esc_attr( $width ) . '">';
			$output .= '<div class="' . esc_attr( $this->shortcode . '_content' ) . '"' . $el_inner_style . '>';
				$output .= wptexturize( do_shortcode( $content ) );
			$output .= '</div>';
			if ( $triangle != '' ) $output .= '<div class="' . esc_attr( $this->shortcode . '_triangle_box' ) . '" ' . $triangle_style . '></div>';
		$output .= '</div>';

		
		$output = apply_filters( 'bt_bb_general_output', $output, $atts );
		$output = apply_filters( $this->shortcode . '_output', $output, $atts );

		return $output;

	}

	function map_shortcode() {
		bt_bb_map( $this->shortcode, array( 'name' => esc_html__( 'Column', 'squadrone' ), 'description' => esc_html__( 'Column element', 'squadrone' ), 'width_param' => 'width', 'container' => 'vertical', 'accept' => array( 'bt_bb_section' => false, 'bt_bb_row' => false, 'bt_bb_column' => false, 'bt_bb_column_inner' => false, 'bt_bb_tab_item' => false, 'bt_bb_accordion_item' => false, 'bt_bb_cost_calculator_item' => false, 'bt_cc_group' => false, 'bt_cc_multiply' => false, 'bt_cc_item' => false, 'bt_bb_content_slider_item' => false, 'bt_bb_google_maps_location' => false, '_content' => false ), 'accept_all' => true, 'toggle' => false,
			'params' => array(
				array( 'param_name' => 'align', 'type' => 'dropdown', 'heading' => esc_html__( 'Align', 'squadrone' ), 'preview' => true,
					'value' => array(
						esc_html__( 'Left', 'squadrone' ) => 'left',
						esc_html__( 'Right', 'squadrone' ) => 'right',
						esc_html__( 'Center', 'squadrone' ) => 'center'
					)
				),
				array( 'param_name' => 'vertical_align', 'type' => 'dropdown', 'heading' => esc_html__( 'Vertical align', 'squadrone' ), 'preview' => true,
					'value' => array(
						esc_html__( 'Top', 'squadrone' )     => 'top',
						esc_html__( 'Middle', 'squadrone' )  => 'middle',
						esc_html__( 'Bottom', 'squadrone' )  => 'bottom'
					)
				),
				array( 'param_name' => 'animation', 'type' => 'dropdown', 'heading' => esc_html__( 'Animation', 'squadrone' ), 'preview' => true,
					'value' => array(
						esc_html__( 'No Animation', 'squadrone' ) => 'no_animation',
						esc_html__( 'Fade In', 'squadrone' ) => 'fade_in',
						esc_html__( 'Move Up', 'squadrone' ) => 'move_up',
						esc_html__( 'Move Left', 'squadrone' ) => 'move_left',
						esc_html__( 'Move Right', 'squadrone' ) => 'move_right',
						esc_html__( 'Move Down', 'squadrone' ) => 'move_down',
						esc_html__( 'Zoom in', 'squadrone' ) => 'zoom_in',
						esc_html__( 'Zoom out', 'squadrone' ) => 'zoom_out',
						esc_html__( 'Fade In / Move Up', 'squadrone' ) => 'fade_in move_up',
						esc_html__( 'Fade In / Move Left', 'squadrone' ) => 'fade_in move_left',
						esc_html__( 'Fade In / Move Right', 'squadrone' ) => 'fade_in move_right',
						esc_html__( 'Fade In / Move Down', 'squadrone' ) => 'fade_in move_down',
						esc_html__( 'Fade In / Zoom in', 'squadrone' ) => 'fade_in zoom_in',
						esc_html__( 'Fade In / Zoom out', 'squadrone' ) => 'fade_in zoom_out'
					)
				),				
				array( 'param_name' => 'padding', 'type' => 'dropdown', 'heading' => esc_html__( 'Padding', 'squadrone' ), 'preview' => true,
					'value' => array(
						esc_html__( 'Normal', 'squadrone' ) => 'normal',
						esc_html__( 'Double', 'squadrone' ) => 'double',
						esc_html__( 'Text Indent', 'squadrone' ) => 'text_indent'				
					)
				),
				array( 'param_name' => 'background_image', 'type' => 'attach_image',  'preview' => true, 'heading' => esc_html__( 'Background image', 'squadrone' ), 'group' => esc_html__( 'Design', 'squadrone' ) ),
				array( 'param_name' => 'inner_background_image', 'type' => 'attach_image',  'preview' => true, 'heading' => esc_html__( 'Inner background image', 'squadrone' ), 'group' => esc_html__( 'Design', 'squadrone' ) ),
				array( 'param_name' => 'background_color', 'type' => 'colorpicker', 'heading' => esc_html__( 'Background color', 'squadrone' ), 'group' => esc_html__( 'Design', 'squadrone' ) ),
				array( 'param_name' => 'inner_background_color', 'type' => 'colorpicker', 'heading' => esc_html__( 'Inner background color', 'squadrone' ), 'group' => esc_html__( 'Design', 'squadrone' ) ),
				array( 'param_name' => 'opacity', 'type' => 'textfield', 'heading' => esc_html__( 'Background color opacity (e.g. 0.4)', 'squadrone' ), 'group' => esc_html__( 'Design', 'squadrone' ) ),
				array( 'param_name' => 'triangle', 'type' => 'dropdown', 'heading' => esc_html__( 'Triangle', 'squadrone' ),  'group' => esc_html__( 'Design', 'squadrone' ), 'description' => 'Set column background color in order to manage triangle color',
					'value' => array(
						esc_html__( 'No', 'squadrone' ) => '',
						esc_html__( 'Top', 'squadrone' ) => 'top',
						esc_html__( 'Bottom', 'squadrone' ) => 'bottom',
						esc_html__( 'Left', 'squadrone' ) => 'left',
						esc_html__( 'Right', 'squadrone' ) => 'right'
					)
				)
			)
		) );
	}

	static function hex2rgb( $hex ) {
		$hex = str_replace( '#', '', $hex );
		if ( strlen( $hex ) == 3 ) {
			$r = hexdec( substr( $hex, 0, 1 ) . substr( $hex, 0, 1 ) );
			$g = hexdec( substr( $hex, 1, 1 ) . substr( $hex, 1, 1 ) );
			$b = hexdec( substr( $hex, 2, 1 ) . substr( $hex, 2, 1 ) );
		} else {
			$r = hexdec( substr( $hex, 0, 2 ) );
			$g = hexdec( substr( $hex, 2, 2 ) );
			$b = hexdec( substr( $hex, 4, 2 ) );
		}
		$rgb = array( $r, $g, $b );
		return $rgb;
	}	

}